<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Corporate_Hub
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="http://gmpg.org/xfn/11">
    <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">

    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<!-- full-screen-layout/boxed-layout -->
<?php if (corporate_hub_get_option('homepage-layout-option') == 'full-width') {
    $corporate_hub_homepage_layout = 'full-screen-layout';
} elseif (corporate_hub_get_option('homepage-layout-option') == 'boxed') {
    $corporate_hub_homepage_layout = 'boxed-layout';
} ?>
<div id="page" class="site site-bg nav-overlay <?php echo esc_attr($corporate_hub_homepage_layout); ?>">
    <a class="skip-link screen-reader-text" href="#main"><?php esc_html_e('Skip to content', 'corporate-hub'); ?></a>

    <header id="masthead" class="site-header" role="banner">
        <div class="top-header">
            <div class="container">
                <div class="header-main">
                    <div class="header-left">
                        <?php $corporate_secondary_logo_image = esc_url(corporate_hub_get_option('secondary_logo_image')); ?>
                        <?php 
                        $corporate_hub_sec_logo_enable = '';
                        if (empty($corporate_secondary_logo_image)) { 
                            $corporate_hub_sec_logo_enable = 'secondary-logo-disabled';
                        } else {
                            $corporate_hub_sec_logo_enable = 'secondary-logo-enabled';
                        }?>
                        <div class="site-branding <?php echo esc_attr($corporate_hub_sec_logo_enable); ?>">
                            <div class="main-logo">
                                <?php corporate_hub_the_custom_logo();  ?>
                            </div>
                            <?php $corporate_secondary_logo_image = esc_url(corporate_hub_get_option('secondary_logo_image')); ?>
                            <?php if (!empty($corporate_secondary_logo_image)) { ?>
                            <div class="secondary-logo">
                                <a href='<?php echo home_url(); ?>'>
                                    <img src="<?php echo esc_url($corporate_secondary_logo_image); ?>"/>
                                </a>
                            </div>
                            <?php } ?>
                            <span class="site-title primary-font">
                                <a href="<?php echo esc_url(home_url('/')); ?>" rel="home">
                                    <?php bloginfo('name'); ?>
                                </a>
                            </span>
                            <?php $description = get_bloginfo('description', 'display');
                            if ($description || is_customize_preview()) : ?>
                                <p class="site-description">
                                    <?php echo esc_html($description); ?>
                                </p>
                            <?php
                            endif; ?>
                        </div><!-- .site-branding -->
                    </div>
                    <div class="header-center">
                        <nav id="site-navigation" class="main-navigation hidden-xs hidden-sm" role="navigation">
                            <?php wp_nav_menu(array(
                                'theme_location' => 'primary',
                                'menu_id' => 'primary-menu',
                                'container' => 'div',
                                'container_class' => 'menu'
                            )); ?>
                        </nav><!-- #site-navigation -->
                    </div>
                    <div class="header-right">
                        <ul class="navbar-extras">
                            <li class="navbar-item">
                                <a href="#" class="search-button"><i class="icon twp-icon ion-ios-search"></i></a>
                                <!-- end search-button -->
                            </li>
                            <li class="navbar-item">
                                <div class="visible-sm visible-xs">
                                    <span class="screen-reader-text">
                                        <?php esc_html_e('Primary Menu', 'corporate-hub'); ?>
                                    </span>
                                    <a class="offcanvas-toggle" href="#">
                                        <div class="twp-hamburger">
                                            <span></span>
                                            <span></span>
                                            <span></span>
                                        </div>
                                    </a>
                                </div>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <!-- #masthead -->
    <?php get_template_part( 'template-parts/header/offcanvas', 'menu' ); ?>
    <!-- Innerpage Header Begins Here -->
    <?php
        if (is_front_page() && !is_home()) {

        } else {
            do_action('corporate-hub-page-inner-title');
        }
    ?>
    <!-- Innerpage Header Ends Here -->
    <div class="search-box">
        <div class="middle-div">
            <div class="inner">
                <div class="searchbox-wrapper">
                    <h4><?php echo esc_html__('SEARCH','corporate-hub' ); ?></h4>
                    <?php get_search_form(); ?>
                    <span class="close-search">
                        <i class="icon twp-icon ion-ios-close-empty"></i>
                    </span>
                </div>
            </div>
        </div>
    </div>
    <div id="content" class="site-content">